import { Tooltip } from "antd";
import { useEffect, useState } from "react";
import { FormatDatetime } from "../../utils";
import { useTranslation } from "react-i18next";

// Calculate elapsed time in seconds, minutes, hours, or days
function calculatedTimeAgo(startTime, t) {
  const currentTime = new Date();
  const elapsedMilliseconds = currentTime - new Date(startTime);

  let timeAgoText;

  if (elapsedMilliseconds < 60000) {
    const secondsAgo = Math.floor(elapsedMilliseconds / 1000);
    timeAgoText =
      secondsAgo === 0
        ? "just now"
        : secondsAgo === 1
        ? t("liveTimeAgo.second", { count: secondsAgo })
        : t("liveTimeAgo.second_plural", { count: secondsAgo });
  } else if (elapsedMilliseconds < 3600000) {
    const minutesAgo = Math.floor(elapsedMilliseconds / 60000);
    timeAgoText =
      minutesAgo === 1
        ? t("liveTimeAgo.minute", { count: minutesAgo })
        : t("liveTimeAgo.minute_plural", { count: minutesAgo });
  } else if (elapsedMilliseconds < 86400000) {
    const hoursAgo = Math.floor(elapsedMilliseconds / 3600000);
    timeAgoText =
      hoursAgo === 1
        ? t("liveTimeAgo.hour", { count: hoursAgo })
        : t("liveTimeAgo.hour_plural", { count: hoursAgo });
  } else {
    const daysAgo = Math.floor(elapsedMilliseconds / 86400000);
    timeAgoText =
      daysAgo === 1
        ? t("liveTimeAgo.day", { count: daysAgo })
        : t("liveTimeAgo.day_plural", { count: daysAgo });
  }

  return timeAgoText;
}

export default function LiveTimeAgo({ startTime }) {
  const { t } = useTranslation();
  const [timeAgo, setTimeAgo] = useState(calculatedTimeAgo(startTime, t));

  useEffect(() => {
    const interval = setInterval(() => {
      setTimeAgo(calculatedTimeAgo(startTime, t));
    }, 1000); // Update every second

    return () => clearInterval(interval); // Clean up on component unmount
  }, [startTime]);

  return (
    <Tooltip title={FormatDatetime(startTime)}>
      <span>{timeAgo}</span>
    </Tooltip>
  );
}
