import { createContext, useContext, useEffect, useRef } from "react";
import { wsConnectionCustomEventName } from "../utils";

const WebSocketContext = createContext(null);

export const useWebSocketContext = () => useContext(WebSocketContext);

let wsConnectionEvent = null;
let firstConnection = true;

export default function WebSocketProvider({
  children,
  userSession,
  setUserSession,
  isWebSocketReady,
  setIsWebSocketReady,
  notificationApi,
}) {
  const ws = useRef(null);
  const wsMessageCache = useRef([]);

  if (wsConnectionEvent === null) {
    wsConnectionEvent = new CustomEvent(wsConnectionCustomEventName, {
      detail: "wsReconnect",
    });
  }

  const connect = () => {
    setIsWebSocketReady(true);

    /*
    ws.current = new WebSocket(
      `${Constants.WS_ADDRESS}?auth=${userSession}&bts=${BrowserTabSession}`
    );

    ws.current.onopen = () => {
      sideBarContext.setConnectionBadgeStatus("success");
      setIsWebSocketReady(true);

      if (firstConnection) {
        firstConnection = false;
      } else {
        document.dispatchEvent(wsConnectionEvent);
      }

      myFetch("/user/", "GET").then((data) => {
        appContext.userId.current = data.UserId;
        appContext.setUserPermissions(
          data.Permissions === null ? [] : data.Permissions
        );
        appContext.setUsers(data.Users);
        headerContext.setTotalNotifications(data.TotalNotifications);
        sideBarContext.setUsername(data.Username);
        sideBarContext.setAvatar(data.Avatar);
        sideBarContext.setAvailableCategories(
          data.AvailableCategories === null ? [] : data.AvailableCategories
        );
      });

      if (wsMessageCache.current.length > 0) {
        // send cached messages
        wsMessageCache.current.forEach((message) => {
          ws.current.send(JSON.stringify(message));
        });

        wsMessageCache.current = [];
      }
    };

    ws.current.onmessage = (event) => {
      handleWebSocketMessage(
        event,
        navigate,
        notificationApi,
        sideBarContext,
        appContext,
        headerContext,
        groupTasksContext,
        userProfileContext,
        adminAreaRolesContext,
        usersContext,
        consolesContext,
        scannerContext,
        crmContext
      ); 
    };

    ws.current.onclose = (event) => {
      setIsWebSocketReady(false);
      sideBarContext.setConnectionBadgeStatus("error");
      console.warn("closed", event);

      // custom code defined by the backend server
      if (event.code === 4001 || event.code === 4002) {
        //Unauthorized || SessionClosed

        setUserSession();
        window.location.href = "/";
        return;
      }

      if (event.reason.code === 1005) return;

      console.warn("reconnecting...");

      setTimeout(() => connect(), 1000);
    }; */
  };

  const SendSocketMessage = (cmd, body) => {
    if (
      isWebSocketReady &&
      ws.current !== null &&
      ws.current.readyState === 1
    ) {
      ws.current.send(JSON.stringify({ Cmd: cmd, Body: body }));
    } else {
      wsMessageCache.current.push({ Cmd: cmd, Body: body });
    }
  };

  useEffect(() => {
    connect();

    return () => ws.current.close();
  }, []);

  return (
    <WebSocketContext.Provider value={{ SendSocketMessage: SendSocketMessage }}>
      {children}
    </WebSocketContext.Provider>
  );
}
