import { useEffect, useRef, useState } from "react";
import { myFetch } from "../../../utils";
import { useParams } from "react-router-dom";
import { Card, Form } from "antd";
import { MyFormInput } from "../../../Components/MyFormInputs";
import { useTranslation } from "react-i18next";
import {
  RequestState,
  RequestStateItem,
} from "../../../Components/MyRequestStateItem";

export default function StoreSettings() {
  const { t } = useTranslation();

  const { storeId } = useParams();
  const [form] = Form.useForm();

  const [isRequesting, setIsRequesting] = useState(true);
  const [requestState, setRequestState] = useState(RequestState.INIT);
  const [storeData, setStoreData] = useState({});
  const delayTimeout = useRef();

  const companyName = Form.useWatch("companyName", form);
  const phoneNumber = Form.useWatch("phoneNumber", form);
  const email = Form.useWatch("email", form);
  const address = Form.useWatch("address", form);

  useEffect(() => {
    myFetch(`/store/${storeId}`, "GET")
      .then((data) => {
        setStoreData(data.store);

        form.setFieldsValue({
          companyName: data.store.name,
          phoneNumber: data.store.phone_number,
          email: data.store.email,
          address: data.store.address,
        });

        setIsRequesting(false);
      })
      .catch((errStatus) => {
        console.log(errStatus);
      });
  }, []);

  useEffect(() => {
    if (
      companyName === undefined ||
      phoneNumber === undefined ||
      email === undefined ||
      address === undefined
    )
      return;

    if (RequestState.INIT === requestState) {
      setRequestState(RequestState.NOTHING);
      return;
    }

    setRequestState(RequestState.REQUESTING);

    if (delayTimeout.current) {
      clearTimeout(delayTimeout.current);
    }

    delayTimeout.current = setTimeout(() => {
      myFetch(`/store/${storeId}`, "POST", {
        name: companyName,
        phoneNumber,
        email,
        address,
      })
        .then(() => setRequestState(RequestState.SUCCESS))
        .catch((errStatus) => {
          console.log(errStatus);
          setRequestState(RequestState.FAILED);
        });
    }, 500);
  }, [companyName, phoneNumber, email, address]);

  return (
    <>
      <Card
        title={t("storeSettings.pageTitle")}
        loading={isRequesting}
        extra={
          <RequestStateItem
            state={requestState}
            setRequestState={setRequestState}
          />
        }
      >
        <Form form={form} requiredMark={false} layout="vertical">
          <MyFormInput
            formItemName="companyName"
            label={t("common.companyName")}
            inputPlaceholder={t("common.companyNamePlaceholder")}
          />

          <MyFormInput
            formItemName="phoneNumber"
            label={t("common.companyPhoneNumber")}
            inputPlaceholder={t("common.companyPhoneNumberPlaceholder")}
          />

          <MyFormInput
            formItemName="email"
            label={t("common.companyEmail")}
            inputPlaceholder={t("common.companyEmailPlaceholder")}
          />

          <MyFormInput
            formItemName="address"
            label={t("common.companyAddress")}
            inputType="textarea"
            inputPlaceholder={t("common.companyAddressPlaceholder")}
          />
        </Form>
      </Card>
    </>
  );
}
